AssignmentResultModel class

Constructors

AssignmentResultModel({required String documentID, String? key, String? value})

Properties

documentID ↔ String
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setteroverride
key ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
getter/setter pair

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
override
copyWith({String? documentID, String? key, String? value}) → AssignmentResultModel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → AssignmentResultEntity
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

id → const String
packageName → const String