AssignmentViewEntity class

Constructors

AssignmentViewEntity({required String? appId, String? title, String? description, StorageConditionsEntity? conditions})

Properties

appId → String?
final
conditions → StorageConditionsEntity?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

copyWith({String? documentID, String? appId, String? title, String? description, StorageConditionsEntity? conditions}) → AssignmentViewEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → AssignmentViewEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → AssignmentViewEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → AssignmentViewEntity?