RepositorySingleton class

Inheritance

Constructors

RepositorySingleton()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

assignmentRepository(String? appId) → AssignmentRepository?
override
assignmentViewRepository(String? appId) → AssignmentViewRepository?
override
flush(String? appId) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
workflowRepository(String? appId) → WorkflowRepository?
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited