WorkflowTaskEntity class

Constructors

WorkflowTaskEntity({int? seqNumber, TaskEntity? task, WorkflowNotificationEntity? confirmMessage, WorkflowNotificationEntity? rejectMessage, int? responsible})

Properties

confirmMessage → WorkflowNotificationEntity?
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
no setter
rejectMessage → WorkflowNotificationEntity?
final
responsible → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seqNumber → int?
final
task → TaskEntity?
final

Methods

copyWith({String? documentID, int? seqNumber, TaskEntity? task, WorkflowNotificationEntity? confirmMessage, WorkflowNotificationEntity? rejectMessage, int? responsible}) → WorkflowTaskEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → WorkflowTaskEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → WorkflowTaskEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → WorkflowTaskEntity?