TaskEntity class abstract

Constructors

TaskEntity({required String identifier, required String description, required bool executeInstantly})
const

Properties

description → String
final
executeInstantly → bool
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDocument() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map snap, {Map<String, String>? newDocumentIds}) → TaskEntity?